# PCL | Python Configuration Language

PCL is a 'python like' language designed for configuration.
Python Configuration Langauge is designed for systems, and
humans - but also for engineers! Python was chosen due to
its simplicity and 'near natural language' syntax.

## Usage

## Serialization / Deserialization

### YAML

### JSON
